==> common-web-tools-v3-3.3.4.1-sources.jar: common/web/tools/statistics/influxdb/QpsInfo.java <==
package common.web.tools.statistics.influxdb;

import org.influxdb.annotation.Column;
import org.influxdb.annotation.Measurement;

/**
 * @author Administrator
 */
@Measurement(name = "qps_info")
public class QpsInfo {

    @Column(name = "time")
    private long time;

    @Column(name = "api_name", tag = true)
    private String apiName;

    @Column(name = "server_address", tag = true)
    private String serverAddress;

    @Column(name = "server_port")
    private String serverPort;

    @Column(name = "http_response_code",tag = true)
    private String httpResponseCode;

    @Column(name = "err_code", tag = true)
    private String errCode;

    @Column(name = "err_msg")
    private String errMsg;

    @Column(name = "visit_count")
    private int visitCount;

    @Column(name = "max_qps")
    private double maxQps;

    @Column(name = "min_qps")
    private double minQps;

    @Column(name = "real_qps")
    private double realQps;

    public long getTime() {
        return time;
    }

    public String getApiName() {
        return apiName;
    }

    public String getServerAddress() {
        return serverAddress;
    }

    public String getServerPort() {
        return serverPort;
    }

    public String getHttpResponseCode() {
        return httpResponseCode;
    }

    public String getErrCode() {
        return errCode;
    }

    public String getErrMsg() {
        return errMsg;
    }

    public int getVisitCount() {
        return visitCount;
    }

    public double getMaxQps() {
        return maxQps;
    }

    public double getMinQps() {
        return minQps;
    }

    public double getRealQps() {
        return realQps;
    }

    public QpsInfo(Builder builder) {
        this.time = builder.time;
        this.apiName = builder.apiName;
        this.serverAddress = builder.serverAddress;
        this.serverPort = builder.serverPort;
        this.httpResponseCode = builder.httpResponseCode;
        this.errCode = builder.errCode;
        this.errMsg = builder.errMsg;
        this.visitCount = builder.visitCount;
        this.maxQps = builder.maxQps;
        this.minQps = builder.minQps;
        this.realQps = builder.realQps;
    }

    public static class Builder {
        private long time;

        private String apiName;

        private String serverAddress;

        private String serverPort;

        private String httpResponseCode;

        private String errCode;

        private String errMsg;

        private int visitCount;

        private double maxQps;

        private double minQps;

        private double realQps;

        public Builder time(long time) {
            this.time = time;
            return this;
        }

        public Builder apiName(String apiName) {
            this.apiName = apiName;
            return this;
        }

        public Builder serverAddress(String serverAddress) {
            this.serverAddress = serverAddress;
            return this;
        }

        public Builder serverPort(String serverPort) {
            this.serverPort = serverPort;
            return this;
        }

        public Builder httpResponseCode(String httpResponseCode) {
            this.httpResponseCode = httpResponseCode;
            return this;
        }

        public Builder errCode(String errCode) {
            this.errCode = errCode;
            return this;
        }

        public Builder errMsg(String errMsg) {
            this.errMsg = errMsg;
            return this;
        }

        public Builder visitCount(int visitCount) {
            this.visitCount = visitCount;
            return this;
        }

        public Builder maxQps(double maxQps) {
            this.maxQps = maxQps;
            return this;
        }

        public Builder minQps(double minQps) {
            this.minQps = minQps;
            return this;
        }

        public Builder realQps(double realQps) {
            this.realQps = realQps;
            return this;
        }

        public QpsInfo build() {
            return new QpsInfo(this);
        }
    }
}

==> common-web-tools-v3-3.3.5-sources.jar: common/web/tools/statistics/influxdb/QpsInfo.java <==
package common.web.tools.statistics.influxdb;

import org.influxdb.annotation.Column;
import org.influxdb.annotation.Measurement;

/**
 * @author Administrator
 */
@Measurement(name = "qps_info")
public class QpsInfo {

    @Column(name = "time")
    private long time;

    @Column(name = "brand", tag = true)
    private String brand;

    @Column(name = "api_name", tag = true)
    private String apiName;

    @Column(name = "server_address", tag = true)
    private String serverAddress;

    @Column(name = "server_port")
    private String serverPort;

    @Column(name = "http_response_code", tag = true)
    private String httpResponseCode;

    @Column(name = "err_code", tag = true)
    private String errCode;

    @Column(name = "err_msg")
    private String errMsg;

    @Column(name = "visit_count")
    private int visitCount;

    @Column(name = "max_qps")
    private double maxQps;

    @Column(name = "min_qps")
    private double minQps;

    @Column(name = "real_qps")
    private double realQps;

    public long getTime() {
        return time;
    }

    public String getApiName() {
        return apiName;
    }

    public String getServerAddress() {
        return serverAddress;
    }

    public String getServerPort() {
        return serverPort;
    }

    public String getHttpResponseCode() {
        return httpResponseCode;
    }

    public String getErrCode() {
        return errCode;
    }

    public String getErrMsg() {
        return errMsg;
    }

    public int getVisitCount() {
        return visitCount;
    }

    public double getMaxQps() {
        return maxQps;
    }

    public double getMinQps() {
        return minQps;
    }

    public double getRealQps() {
        return realQps;
    }

    public String getBrand() {
        return brand;
    }

    public QpsInfo(Builder builder) {
        this.time = builder.time;
        this.apiName = builder.apiName;
        this.serverAddress = builder.serverAddress;
        this.serverPort = builder.serverPort;
        this.httpResponseCode = builder.httpResponseCode;
        this.errCode = builder.errCode;
        this.errMsg = builder.errMsg;
        this.visitCount = builder.visitCount;
        this.maxQps = builder.maxQps;
        this.minQps = builder.minQps;
        this.realQps = builder.realQps;
        this.brand = builder.brand;
    }

    public static class Builder {
        private long time;

        private String brand;

        private String apiName;

        private String serverAddress;

        private String serverPort;

        private String httpResponseCode;

        private String errCode;

        private String errMsg;

        private int visitCount;

        private double maxQps;

        private double minQps;

        private double realQps;

        public Builder time(long time) {
            this.time = time;
            return this;
        }

        public Builder brand(String brand) {
            this.brand = brand;
            return this;
        }

        public Builder apiName(String apiName) {
            this.apiName = apiName;
            return this;
        }

        public Builder serverAddress(String serverAddress) {
            this.serverAddress = serverAddress;
            return this;
        }

        public Builder serverPort(String serverPort) {
            this.serverPort = serverPort;
            return this;
        }

        public Builder httpResponseCode(String httpResponseCode) {
            this.httpResponseCode = httpResponseCode;
            return this;
        }

        public Builder errCode(String errCode) {
            this.errCode = errCode;
            return this;
        }

        public Builder errMsg(String errMsg) {
            this.errMsg = errMsg;
            return this;
        }

        public Builder visitCount(int visitCount) {
            this.visitCount = visitCount;
            return this;
        }

        public Builder maxQps(double maxQps) {
            this.maxQps = maxQps;
            return this;
        }

        public Builder minQps(double minQps) {
            this.minQps = minQps;
            return this;
        }

        public Builder realQps(double realQps) {
            this.realQps = realQps;
            return this;
        }

        public QpsInfo build() {
            return new QpsInfo(this);
        }
    }
}
